@@ -799,12 +799,12 @@ class TerraformGenerator(TemplateGenerator):
         template = {
             'resource': {},
             'terraform': {
-                'required_version': '> 0.11.0, < 1.1.0'
-            },
-            'provider': {
-                'template': {'version': '~> 2'},
-                'aws': {'version': '>= 2, < 4'},
-                'null': {'version': '>= 2, < 4'},
+                'required_version': '>= 0.12.26, < 1.1.0',
+                'required_providers': {
+                    'aws': {'version': '>= 2, < 4'},
+                    'template': {'version': '~> 2'},
+                    'null': {'version': '>= 2, < 4'}
+                }
             },
             'data': {
                 'aws_caller_identity': {'chalice': {}},
